@@ -1,9 +1,7 @@
 from .learner import *
 from .data import *
 from .models import *
-from .metrics import *
 from .losses import *
-from .callbacks import *
 from .utils import *
 from .gui import *
 from .gt import *
